<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>EllipseInscribedQuad</name>
    <message>
        <location filename="../EllipseInscribedQuad.js" line="+82"/>
        <source>First line</source>
        <translation>Pierwsza linia</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Second line</source>
        <translation>Druga linia</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Third line</source>
        <translation>Trzecia linia</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Fourth line</source>
        <translation>Czwarta linia</translation>
    </message>
    <message>
        <location filename="../EllipseInscribedQuadInit.js" line="+2"/>
        <source>Inscribed in Quadrilateral</source>
        <translation>Wpisana w czworokąt</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw ellipse inscribed in quadrilateral</source>
        <translation>Rysuje elipsę wpisaną w czworokąt</translation>
    </message>
</context>
</TS>
